@@ -5,10 +5,13 @@
 #' Adds year, month and day columns to a NZFFD dataset, based on values in 
 #' the "eventDate" column.
 #' 
-#' @param fishd a dataframe imported from the NZFFD using [nzffdr_import()], which contains the column "eventDate"
+#' @param fishd a dataframe imported from the NZFFD using \code{nzffdr_import()}, which contains the column \code{"eventDate"}
 #'
 #' @return a NZFFD dataframe, with year, month and day columns added.
 #'
+#' @importFrom tidyr separate
+#' @importFrom rlang .data
+#'
 #' @examples
 #' nzffdr_add_dates(nzffdr::nzffdr_data)
 #' 
@@ -20,11 +23,13 @@ nzffdr_add_dates <- function(fishd){
   }
   
   # add year, month, day columns
-  fishd$year <- as.integer(sapply(fishd$eventDate,
-                                  function(x) unlist(strsplit(x, "\\-"))[1]))
-  fishd$month <- as.integer(sapply(fishd$eventDate,
-                                   function(x) unlist(strsplit(x, "\\-"))[2]))
-  fishd$day <- as.integer(sapply(fishd$eventDate,
-                                 function(x) unlist(strsplit(x, "\\-"))[3]))
+  fishd <-  tidyr::separate(data = fishd,
+                    col = .data$eventDate,
+                    into = c("year", "month", "day"),
+                    sep = "-",
+                    remove = FALSE,
+                    fill = "right",
+                    convert = TRUE)
+
 return(fishd)
 }
\ No newline at end of file
